****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_padmit.sas  
*
* Created (mm/dd/yyyy): 03/01/2018
* Last modified: 
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
* 	This program will expand the aggregated PADMIT parameter such that it can be used to extract
*  	claims in the MSCDM. 
*
*  Program inputs:                                                                                   
*	-dataset containing the padmit to expand
* 
*  Program outputs:                                                                                                                                       
*	-dataset with the expanded padmit
* 
* PARAMETERS:
*  	-InFile	= Name of the dataset containing the padmit to expand
*  	-Var	= Name of the varaible containing the padmit variable
*  	-OutFile= Name of the dataset with the expanded padmit
*
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO:
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference ex ternal documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%MACRO ms_padmit(InFile=, Var=, OutFile=);

%put =====> MACRO CALLED: ms_padmit v1.0;

	data &OutFile.(rename=padmit1=padmit);
	set &InFile;
	format Padmit1 $1.;

	* All Caresetting and Principal;
	if &var. eq "" then do;
		Padmit1="*";
		output;		
	end;
	else do;
      Numarg=length(compress(&var.," '"))/1;
      do i=1 to Numarg;	  	 
         Padmit1=substr(compress(scan(&var.,i),"'"),1,1);
		 output;
      end;
   	end;
	drop i Numarg padmit;
	run;

%put NOTE: ********END OF MACRO: ms_padmit v1.0********;

%MEND ms_padmit;
