****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_qrpe_setloopmacrovars.sas  
*
* Created (mm/dd/yyyy): 02/01/2018
* Last modified:
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
* 	This macro is used to set macro variables from cohortfile related to a particular group
*
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%macro ms_qrpe_setloopmacrovars();	

	%put =====> MACRO CALLED: ms_qrpe_setloopmacrovars v1.0;

	/** CohortFile **/
	data _null_;
		set infolder.&COHORTFILE.;
		if _n_ = &Group. then do;
			call symputx('ITGROUP',strip(Group));            

			*Age stratification;
			if missing(agestrat) then do;
				call symputx("agestrat","00-01 02-04 05-09 10-14 15-18 19-21 22-44 45-64 65-74 75+");
			end;
			else do;
				call symputx("agestrat",agestrat);
			end;

			*Sex values applicable to demographics;
			if missing(Sex) then do;
				call symputx("DemogSex","'F' 'M' 'U' 'A'");
			end;
			else do;
				call symputx('DemogSex',upcase(Sex));
			end;

			*Race values applicable to demographics;
			if missing(Race) then do;
				call symputx("DemogRace","'0' '1' '2' '3' '4' '5'");
			end;
			else do;
				call symputx("DemogRace",upcase(Race));
			end;

			*Hispanic values applicable to demographics;
			if missing(Hispanic) then do;
				call symputx("DemogHispanic","'Y' 'N' 'U'");
			end;
			else do;
				call symputx("DemogHispanic",upcase(Hispanic));
			end;	

			*Caresetting values applicable to encounters;
			if missing(caresetting) then do;
				call symputx("EncCaresetting","'IP' 'AV' 'IS' 'ED' 'OA'");
			end;
			else do;
				call symputx("EncCaresetting",upcase(caresetting));
			end;	

			*Remove encounters that end after ENDDATE;
			if missing(truncyn) then do;
				call symputx("truncyn","N");
			end; 
			else do;
				call symputx("truncyn",upcase(truncyn));
			end;
		end;
	run;

	%put NOTE: ******** END OF MACRO: ms_qrpe_initmacrovariables v1.0 ********;

%mend ms_qrpe_setloopmacrovars;
